@@ -9,6 +9,8 @@ import (
 	"os"
 	"strings"
 
+	"github.com/cli/cli/v2/internal/prompter"
+
 	"github.com/MakeNowJust/heredoc"
 	"github.com/cli/cli/v2/api"
 	"github.com/cli/cli/v2/internal/gh"
@@ -27,7 +29,7 @@ type SetOptions struct {
 	IO         *iostreams.IOStreams
 	Config     func() (gh.Config, error)
 	BaseRepo   func() (ghrepo.Interface, error)
-	Prompter   iprompter
+	Prompter   prompter.Prompter
 
 	RandomOverride func() io.Reader
 
@@ -43,10 +45,6 @@ type SetOptions struct {
 	Application     string
 }
 
-type iprompter interface {
-	Password(string) (string, error)
-}
-
 func NewCmdSet(f *cmdutil.Factory, runF func(*SetOptions) error) *cobra.Command {
 	opts := &SetOptions{
 		IO:         f.IOStreams,
@@ -77,6 +75,9 @@ func NewCmdSet(f *cmdutil.Factory, runF func(*SetOptions) error) *cobra.Command
 			# Read secret value from an environment variable
 			$ gh secret set MYSECRET --body "$ENV_VALUE"
 
+			# Set secret for a specific remote repository
+			$ gh secret set MYSECRET --repo origin/repo --body "$ENV_VALUE"
+
 			# Read secret value from a file
 			$ gh secret set MYSECRET < myfile.txt
 
@@ -103,8 +104,19 @@ func NewCmdSet(f *cmdutil.Factory, runF func(*SetOptions) error) *cobra.Command
 		`),
 		Args: cobra.MaximumNArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
-			// support `-R, --repo` override
+			// If the user specified a repo directly, then we're using the OverrideBaseRepoFunc set by EnableRepoOverride
+			// So there's no reason to use the specialised BaseRepoFunc that requires remote disambiguation.
 			opts.BaseRepo = f.BaseRepo
+			if !cmd.Flags().Changed("repo") {
+				// If they haven't specified a repo directly, then we will wrap the BaseRepoFunc in one that errors if
+				// there might be multiple valid remotes.
+				opts.BaseRepo = shared.RequireNoAmbiguityBaseRepoFunc(opts.BaseRepo, f.Remotes)
+				// But if we are able to prompt, then we will wrap that up in a BaseRepoFunc that can prompt the user to
+				// resolve the ambiguity.
+				if opts.IO.CanPrompt() {
+					opts.BaseRepo = shared.PromptWhenAmbiguousBaseRepoFunc(opts.BaseRepo, f.IOStreams, f.Prompter)
+				}
+			}
 
 			if err := cmdutil.MutuallyExclusive("specify only one of `--org`, `--env`, or `--user`", opts.OrgName != "", opts.EnvName != "", opts.UserSecrets); err != nil {
 				return err
@@ -166,6 +178,27 @@ func NewCmdSet(f *cmdutil.Factory, runF func(*SetOptions) error) *cobra.Command
 }
 
 func setRun(opts *SetOptions) error {
+	orgName := opts.OrgName
+	envName := opts.EnvName
+
+	var host string
+	var baseRepo ghrepo.Interface
+	if orgName == "" && !opts.UserSecrets {
+		var err error
+		baseRepo, err = opts.BaseRepo()
+		if err != nil {
+			return err
+		}
+
+		host = baseRepo.RepoHost()
+	} else {
+		cfg, err := opts.Config()
+		if err != nil {
+			return err
+		}
+		host, _ = cfg.Authentication().DefaultHost()
+	}
+
 	secrets, err := getSecretsFromOptions(opts)
 	if err != nil {
 		return err
@@ -177,25 +210,6 @@ func setRun(opts *SetOptions) error {
 	}
 	client := api.NewClientFromHTTP(c)
 
-	orgName := opts.OrgName
-	envName := opts.EnvName
-
-	var host string
-	var baseRepo ghrepo.Interface
-	if orgName == "" && !opts.UserSecrets {
-		baseRepo, err = opts.BaseRepo()
-		if err != nil {
-			return err
-		}
-		host = baseRepo.RepoHost()
-	} else {
-		cfg, err := opts.Config()
-		if err != nil {
-			return err
-		}
-		host, _ = cfg.Authentication().DefaultHost()
-	}
-
 	secretEntity, err := shared.GetSecretEntity(orgName, envName, opts.UserSecrets)
 	if err != nil {
 		return err
